==> semantik_0.6.5.orig.tar.gz: semantik-0.6.5.orig/src/Magyaraz.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QtDebug>
#include <QTextEdit>
#include <QKeyEvent>
#include <QScrollBar>
#include <QCompleter>
#include <QTreeView>
#include <QHeaderView>
#include <QAction>
#include <QStandardItemModel>
#include "Prmza.h"
#include "Jelzpn.h"
#include "Magyaraz.h"
#include "con.h" 
																			#include "tslabels.h"

/*!
 * @praise Vishnu
 */
nztv::nztv(QWidget *felvnl,jelzpn *megkap) : QTextEdit(felvnl)
<%
	kidlgz=megkap;
	nztvh *klsirz=new nztvh(document());
	connect(this,SIGNAL(textChanged()),this,SLOT(nybnvn()));

	jlzpnt=0;
	eler=0;
%>

void nztv::kitzjl()
<%
	fldlgz=new QCompleter(this);
	bprl=new QCompleter(this);
	QTreeView *irnyjl=0;

	QStandardItemModel *prmz=new QStandardItemModel(this);
	fillloc(prmz);
	irnyjl=new QTreeView;
	bprl->setPopup(irnyjl);
	bprl->setModel(prmz);
	bprl->setWidget(this);
	bprl->setCompletionMode(QCompleter::PopupCompletion);
	bprl->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
	bprl->setCaseSensitivity(Qt::CaseInsensitive);
	irnyjl->header()->hide();
	irnyjl->header()->setStretchLastSection(0);
	irnyjl->header()->setResizeMode(0,QHeaderView::ResizeToContents);
	irnyjl->header()->setResizeMode(1,QHeaderView::Stretch);
	irnyjl->setRootIsDecorated(0);
	QObject::connect(bprl,SIGNAL(activated(const QString&)),this,SLOT(prl(const QString&)));

	QStandardItemModel *mrtdt=new QStandardItemModel(this);
        fillglo(mrtdt);
	irnyjl=new QTreeView;
	fldlgz->setPopup(irnyjl);
	fldlgz->setModel(mrtdt);
	fldlgz->setWidget(this);
	fldlgz->setCompletionMode(QCompleter::PopupCompletion);
	fldlgz->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
	fldlgz->setCaseSensitivity(Qt::CaseInsensitive);
	irnyjl->header()->setStretchLastSection(0);
	irnyjl->header()->setResizeMode(0,QHeaderView::ResizeToContents);
	irnyjl->header()->setResizeMode(1,QHeaderView::Stretch);
	irnyjl->setRootIsDecorated(0);
	irnyjl->header()->hide();
	QObject::connect(fldlgz,SIGNAL(activated(const QString&)),this,SLOT(prl(const QString&)));

	eler=fldlgz;

	fnqll=new QAction(ts_348,this);
	fnqll->setShortcut(ts_349);
	connect(fnqll,SIGNAL(triggered()),this,SLOT(lnmtat()));
	addAction(fnqll);

#if 0
        QPalette adelk=palette();
        adelk.setBrush(QPalette::Inactive,QPalette::Base,QColor(230,230,230));
        adelk.setBrush(QPalette::Disabled,QPalette::Base,QColor(230,230,230));
        setPalette(adelk);
#endif
%>

void nztv::kelt(const zagv&tqrost)
<%
	int kivalt=tqrost[3].toInt();
	switch(kivalt)
	<%
		case vlsztt:
			<%
				jlzpnt=tqrost[2].toInt();
				if(jlzpnt > 0)
				<%
					eler=bprl;
					prmza *eljar=kidlgz->kket.value(jlzpnt);
					setText(eljar->mgmnkl);
				%>
				else
				<%
					eler=fldlgz;
					setText(kidlgz->mgmnkl);
				%>
			%>
			break;
		default:
			break;
	%>
%>

void nztv::nybnvn()
<%
	if(jlzpnt)
	<%
		prmza *eljar=kidlgz->kket.value(jlzpnt);
		eljar->mgmnkl=toPlainText();
	%>
	else
	<%
		kidlgz->mgmnkl=toPlainText();
	%>
%>

/*!
 * @praise Vishnu
 */
nztvh::nztvh(QTextDocument *p): QSyntaxHighlighter(p)
<%
	sblny mrtdt;

	QTextCharFormat irnyjl;
	irnyjl.setForeground(Qt::darkBlue);
	mrtdt.nybnvn=QRegExp("#[^\n]*");
	irnyjl.setFontItalic(1);
	mrtdt.kidlgz=irnyjl;
	jlzpnt.append(mrtdt);

	QTextCharFormat adelk;
	adelk.setForeground(Qt::darkGreen);
	adelk.setFontWeight(QFont::Bold);
	mrtdt.nybnvn=QRegExp("^\\w+(\\.\\w+)*");
	mrtdt.kidlgz=adelk;
	jlzpnt.append(mrtdt);

%>

void nztvh::highlightBlock(const QString &hzzqjt)
<%
	foreach(sblny mrtdt,jlzpnt)
	<%
		QRegExp irnyjl(mrtdt.nybnvn);
		int i=hzzqjt.indexOf(irnyjl);
		while(i >= 0)
		<%
			int adelk=irnyjl.matchedLength();

			if(hzzqjt[i+adelk-1]==QChar('=')) adelk--;
			setFormat(i,adelk,mrtdt.kidlgz);
			i=hzzqjt.indexOf(irnyjl,i + adelk);
		%>
	%>
%>

void nztv::prl(const QString& meghat)
<%
	QTextCursor klsirz=textCursor();
	int adelk=meghat.length() - eler->completionPrefix().length();
	if(eler->completionPrefix().length()>0)
	<%
		klsirz.movePosition(QTextCursor::Left);
		klsirz.movePosition(QTextCursor::EndOfWord);
	%>
	else
	<%
		klsirz.movePosition(QTextCursor::StartOfWord);
	%>
	klsirz.insertText(meghat.right(adelk));
	setTextCursor(klsirz);
%>

void nztv::keyPressEvent(QKeyEvent *mgmnkl)
<%
	if(eler->popup()->isVisible())
	<%
		switch(mgmnkl->key())
		<%
			case Qt::Key_Enter:
			case Qt::Key_Return:
			case Qt::Key_Escape:
			case Qt::Key_Tab:
			case Qt::Key_Backtab:
				mgmnkl->ignore();
				return;
			default:
				break;
		%>
	%>

	QTextEdit::keyPressEvent(mgmnkl);

	bool adelk=mgmnkl->modifiers() &(Qt::ControlModifier | Qt::ShiftModifier);
	if(adelk and mgmnkl->text().isEmpty())
	<%
		return;
	%>

	static QString eow("~!@#$%^&*()_+<%%>|:\"<>?,./;'[]\\-=");

	QTextCursor klsirz=textCursor();
	klsirz.select(QTextCursor::WordUnderCursor);
	QString kket=klsirz.selectedText();

	if(
		kket.length() < 1 or
		mgmnkl->text().isEmpty() or
		eow.contains(mgmnkl->text().right(1)) or
		(mgmnkl->modifiers()!=Qt::NoModifier and !adelk)
	   )
	<%
		eler->popup()->hide();
		return;
	%>
	lnmtat();
%>

void nztv::lnmtat()
<%
	QTextCursor klsirz=textCursor();
	klsirz.select(QTextCursor::WordUnderCursor);
	QString kket=klsirz.selectedText();

	int prmz=klsirz.position();
	klsirz.movePosition(QTextCursor::StartOfWord);
	int mrtdt=klsirz.position();
	klsirz.movePosition(QTextCursor::StartOfLine);
	bool adelk=klsirz.position()==mrtdt;
	klsirz.setPosition(prmz);

	if(!adelk) return;

	if(kket!=eler->completionPrefix())
	<%
		eler->setCompletionPrefix(kket);
		eler->popup()->setCurrentIndex(eler->completionModel()->index(0,0));
	%>
	QRect vnl=cursorRect();
	vnl.setWidth(width());

	QTreeView *irnyjl =(QTreeView*) eler->popup();
	irnyjl->resizeColumnToContents(0);
	irnyjl->resizeColumnToContents(1);
	eler->complete(vnl);
%>

#include "Magyaraz.moc"

==> semantik_0.7.1.orig.tar.gz: semantik-0.7.1/src/Magyaraz.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QtDebug>
#include <QTextEdit>
#include <QKeyEvent>
#include <QScrollBar>
#include <QCompleter>
#include <QTreeView>
#include <QHeaderView>
#include <QAction>
#include <QStandardItemModel>
#include "Prmza.h"
#include "Jelzpn.h"
#include "Magyaraz.h"
#include "con.h" 
																			#include "tslabels.h"

/*!
 * @praise Vishnu
 */
nztv::nztv(QWidget *felvnl,jelzpn *nybnvn) : QTextEdit(felvnl)
<%
	kidlgz=nybnvn;
	nztvh *klsirz=new nztvh(document());
	connect(this,SIGNAL(textChanged()),this,SLOT(megkap()));

	jlzpnt=0;
	eler=0;
%>

void nztv::kitzjl()
<%
	kket=new QCompleter(this);
	bprl=new QCompleter(this);
	QTreeView *irnyjl=0;

	QStandardItemModel *prmz=new QStandardItemModel(this);
	fillloc(prmz);
	irnyjl=new QTreeView;
	bprl->setPopup(irnyjl);
	bprl->setModel(prmz);
	bprl->setWidget(this);
	bprl->setCompletionMode(QCompleter::PopupCompletion);
	bprl->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
	bprl->setCaseSensitivity(Qt::CaseInsensitive);
	irnyjl->header()->hide();
	irnyjl->header()->setStretchLastSection(0);
	irnyjl->header()->setResizeMode(0,QHeaderView::ResizeToContents);
	irnyjl->header()->setResizeMode(1,QHeaderView::Stretch);
	irnyjl->setRootIsDecorated(0);
	QObject::connect(bprl,SIGNAL(activated(const QString&)),this,SLOT(prl(const QString&)));

	QStandardItemModel *mrtdt=new QStandardItemModel(this);
        fillglo(mrtdt);
	irnyjl=new QTreeView;
	kket->setPopup(irnyjl);
	kket->setModel(mrtdt);
	kket->setWidget(this);
	kket->setCompletionMode(QCompleter::PopupCompletion);
	kket->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
	kket->setCaseSensitivity(Qt::CaseInsensitive);
	irnyjl->header()->setStretchLastSection(0);
	irnyjl->header()->setResizeMode(0,QHeaderView::ResizeToContents);
	irnyjl->header()->setResizeMode(1,QHeaderView::Stretch);
	irnyjl->setRootIsDecorated(0);
	irnyjl->header()->hide();
	QObject::connect(kket,SIGNAL(activated(const QString&)),this,SLOT(prl(const QString&)));

	eler=kket;

	fnqll=new QAction(ts_349,this);
	fnqll->setShortcut(ts_350);
	connect(fnqll,SIGNAL(triggered()),this,SLOT(lnmtat()));
	addAction(fnqll);

#if 0
        QPalette adelk=palette();
        adelk.setBrush(QPalette::Inactive,QPalette::Base,QColor(230,230,230));
        adelk.setBrush(QPalette::Disabled,QPalette::Base,QColor(230,230,230));
        setPalette(adelk);
#endif
%>

void nztv::kivalt(const zagv&tqrost)
<%
	int fldlgz=tqrost[3].toInt();
	switch(fldlgz)
	<%
		case vlsztt:
			<%
				jlzpnt=tqrost[2].toInt();
				if(jlzpnt > 0)
				<%
					eler=bprl;
					prmza *eljar=kidlgz->kket.value(jlzpnt);
					setText(eljar->mgmnkl);
				%>
				else
				<%
					eler=kket;
					setText(kidlgz->mgmnkl);
				%>
			%>
			break;
		default:
			break;
	%>
%>

void nztv::megkap()
<%
	if(jlzpnt)
	<%
		prmza *eljar=kidlgz->kket.value(jlzpnt);
		eljar->mgmnkl=toPlainText();
	%>
	else
	<%
		kidlgz->mgmnkl=toPlainText();
	%>
%>

/*!
 * @praise Vishnu
 */
nztvh::nztvh(QTextDocument *p): QSyntaxHighlighter(p)
<%
	sblny mrtdt;

	QTextCharFormat irnyjl;
	irnyjl.setForeground(Qt::darkBlue);
	mrtdt.kitzjl=QRegExp("#[^\n]*");
	irnyjl.setFontItalic(1);
	mrtdt.jlzpnt=irnyjl;
	jlzpnt.append(mrtdt);

	QTextCharFormat adelk;
	adelk.setForeground(Qt::darkGreen);
	adelk.setFontWeight(QFont::Bold);
	mrtdt.kitzjl=QRegExp("^\\w+(\\.\\w+)*");
	mrtdt.jlzpnt=adelk;
	jlzpnt.append(mrtdt);

%>

void nztvh::highlightBlock(const QString &hzzqjt)
<%
	foreach(sblny mrtdt,jlzpnt)
	<%
		QRegExp irnyjl(mrtdt.kitzjl);
		int i=hzzqjt.indexOf(irnyjl);
		while(i >= 0)
		<%
			int adelk=irnyjl.matchedLength();

			if(hzzqjt[i+adelk-1]==QChar('=')) adelk--;
			setFormat(i,adelk,mrtdt.jlzpnt);
			i=hzzqjt.indexOf(irnyjl,i + adelk);
		%>
	%>
%>

void nztv::prl(const QString& meghat)
<%
	QTextCursor klsirz=textCursor();
	int adelk=meghat.length() - eler->completionPrefix().length();
	if(eler->completionPrefix().length()>0)
	<%
		klsirz.movePosition(QTextCursor::Left);
		klsirz.movePosition(QTextCursor::EndOfWord);
	%>
	else
	<%
		klsirz.movePosition(QTextCursor::StartOfWord);
	%>
	klsirz.insertText(meghat.right(adelk));
	setTextCursor(klsirz);
%>

void nztv::keyPressEvent(QKeyEvent *mgmnkl)
<%
	if(eler->popup()->isVisible())
	<%
		switch(mgmnkl->key())
		<%
			case Qt::Key_Enter:
			case Qt::Key_Return:
			case Qt::Key_Escape:
			case Qt::Key_Tab:
			case Qt::Key_Backtab:
				mgmnkl->ignore();
				return;
			default:
				break;
		%>
	%>

	QTextEdit::keyPressEvent(mgmnkl);

	bool adelk=mgmnkl->modifiers() &(Qt::ControlModifier | Qt::ShiftModifier);
	if(adelk and mgmnkl->text().isEmpty())
	<%
		return;
	%>

	static QString eow("~!@#$%^&*()_+<%%>|:\"<>?,./;'[]\\-=");

	QTextCursor klsirz=textCursor();
	klsirz.select(QTextCursor::WordUnderCursor);
	QString fldlgz=klsirz.selectedText();

	if(
		fldlgz.length() < 1 or
		mgmnkl->text().isEmpty() or
		eow.contains(mgmnkl->text().right(1)) or
		(mgmnkl->modifiers()!=Qt::NoModifier and !adelk)
	   )
	<%
		eler->popup()->hide();
		return;
	%>
	lnmtat();
%>

void nztv::lnmtat()
<%
	QTextCursor klsirz=textCursor();
	klsirz.select(QTextCursor::WordUnderCursor);
	QString fldlgz=klsirz.selectedText();

	int prmz=klsirz.position();
	klsirz.movePosition(QTextCursor::StartOfWord);
	int mrtdt=klsirz.position();
	klsirz.movePosition(QTextCursor::StartOfLine);
	bool adelk=klsirz.position()==mrtdt;
	klsirz.setPosition(prmz);

	if(!adelk) return;

	if(fldlgz!=eler->completionPrefix())
	<%
		eler->setCompletionPrefix(fldlgz);
		eler->popup()->setCurrentIndex(eler->completionModel()->index(0,0));
	%>
	QRect vnl=cursorRect();
	vnl.setWidth(width());

	QTreeView *irnyjl =(QTreeView*) eler->popup();
	irnyjl->resizeColumnToContents(0);
	irnyjl->resizeColumnToContents(1);
	eler->complete(vnl);
%>

#include "Magyaraz.moc"
